# Generated by Django 4.0.3 on 2022-04-25 08:24

import wagtail.blocks
import wagtail.fields
import wagtail.images.blocks
from django.db import migrations
from wagtail.blocks.stream_block import StreamValue


def plain_to_structured(block):
    modified_items = []

    for item in block["value"]["contact_list"]:
        modified_items.append(
            {
                **item,
                "value": {
                    "person": item["value"],
                    "position": "",
                },
            }
        )

    block["value"]["contact_list"] = modified_items

    return block


def structured_to_plain(block):
    modified_items = []

    for item in block["value"]["contact_list"]:
        modified_items.append({**item, "value": item["value"]["person"]})

    block["value"]["contact_list"] = modified_items

    return block


def get_sidebar_content(page, mapper):
    stream_data = []
    mapped = False

    for block in page.sidebar_content.raw_data:
        if block["type"] == "contact":
            stream_data.append(mapper(block))
            mapped = True

        else:
            stream_data.append(block)

    return stream_data, mapped


def migrate(apps, mapper):
    DistrictCenterPage = apps.get_model("district", "DistrictCenterPage")

    for page in DistrictCenterPage.objects.all():
        sidebar_content, mapped = get_sidebar_content(page, mapper)

        if mapped:
            page.sidebar_content = StreamValue(
                page.sidebar_content, sidebar_content, is_lazy=True
            )
            page.save()


def forwards(apps, schema_editor):
    migrate(apps, plain_to_structured)


def backwards(apps, schema_editor):
    migrate(apps, structured_to_plain)


class Migration(migrations.Migration):
    dependencies = [
        ("district", "0055_alter_districtcenterpage_content_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="districtcenterpage",
            name="sidebar_content",
            field=wagtail.fields.StreamField(
                [
                    (
                        "address",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "title",
                                    wagtail.blocks.CharBlock(
                                        label="Titulek", required=True
                                    ),
                                ),
                                (
                                    "map_image",
                                    wagtail.images.blocks.ImageChooserBlock(
                                        label="Obrázek mapy", required=False
                                    ),
                                ),
                                (
                                    "map_link",
                                    wagtail.blocks.URLBlock(
                                        label="Odkaz na detail mapy", required=False
                                    ),
                                ),
                                (
                                    "address",
                                    wagtail.blocks.TextBlock(
                                        label="Adresa", required=True
                                    ),
                                ),
                                (
                                    "address_info",
                                    wagtail.blocks.TextBlock(
                                        label="Info k adrese", required=False
                                    ),
                                ),
                            ]
                        ),
                    ),
                    (
                        "contact",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "title",
                                    wagtail.blocks.CharBlock(
                                        label="Titulek", required=True
                                    ),
                                ),
                                (
                                    "contact_list",
                                    wagtail.blocks.ListBlock(
                                        wagtail.blocks.StructBlock(
                                            [
                                                (
                                                    "person",
                                                    wagtail.blocks.PageChooserBlock(
                                                        label="Osoba",
                                                        page_type=[
                                                            "district.DistrictPersonPage"
                                                        ],
                                                    ),
                                                ),
                                                (
                                                    "position",
                                                    wagtail.blocks.CharBlock(
                                                        label="Pozice", required=False
                                                    ),
                                                ),
                                            ]
                                        )
                                    ),
                                ),
                            ]
                        ),
                    ),
                ],
                blank=True,
                verbose_name="Obsah bočního panelu",
            ),
        ),
        migrations.AlterField(
            model_name="districtcenterpage",
            name="text",
            field=wagtail.fields.RichTextField(
                blank=True, null=True, verbose_name="Text"
            ),
        ),
        migrations.RunPython(forwards, backwards),
    ]
